#  Depth-invariant processing algorithm to produce depth-invariant index images
#  from bands 2 (blue: 453.4-469.2), 3 (green: 531.1-543.5 nm), 4 (green: 571.9-584.3 nm),
#  and 5  (red: 630.7-643.2 nm) of a CASI image of Cockburn Harbour.
#
#  Band 2 = @1, Band 3 = @2, Band 4 = @3, Band 5 = @4
#
#  Input data needed are:
#
#  1) The deep water reflectances in each band, Lsi (= average deep water reflectance - 2 standard
#      deviations) and is represented by constants "deepwaterx" below.
#
#  2) The ratio of the attenuation coefficients ki/kj for each band pair, represented by constants "kikjratio" below.

	const casiband2 = @1 ;
	const casiband3 = @2 ;
	const casiband4 = @3 ;
	const casiband5 = @4 ;

	const deepwater2 = 576 ;
	const deepwater3 = 344 ;
	const deepwater4 = 186 ;
	const deepwater5 = 83 ;
               
	const k2k4ratio = 0.56688 ;
	const k3k4ratio = 0.73393 ;
	const k3k5ratio = 0.64990 ;
	

#	Note: Output images need to be Float (32 bit) and masked areas should left as zero.
#
#	Calculating depth-invariant bottom index image for bands 3 and 4.

	IF (casiband3 > 0)  ln(casiband3 - deepwater3) - ( k3k4ratio * ln(casiband4 - deepwater4) )  
	ELSE 0 ;

#	Calculating depth-invariant bottom index image for bands 2 and 4.

	IF (casiband2 > 0)  ln(casiband2 - deepwater2) - ( k2k4ratio * ln(casiband4 - deepwater4) ) 
	ELSE 0 ;

#	Calculating depth-invariant bottom index image for bands 3 and 5.

	IF (casiband3 > 0)  ln(casiband3 - deepwater3) - ( k3k5ratio * ln(casiband5 - deepwater5) )  
	ELSE 0 ;